/*
  $Header: TYPES.H 3.3 87/12/12 00:46:54 Bob Exp $

                          The Conference Mail System

              This module was originally written by Bob Hartman
                       Sysop of FidoNet node 1:132/101

   Spark Software, 427-3 Amherst St, CS 2032, Suite 232, Nashua, NH 03061

 The Conference Mail System  is a  complete Echomail processing package.  It
 is a superset of the original  Echomail utilities created by Jeff Rush, and
 also contains ideas gleaned from the  ARCmail,  Renum,  oMMM, MGM, and Opus
 programs that were created by various software authors.

 This program source code is being released with the following provisions:

 1.  You are  free to make  changes to this source  code for use on your own
 machine,  however,  altered source files may not be distributed without the 
 consent of Spark Software.

 2.  You may distribute "patches"  or  "diff" files for any changes that you
 have made, provided that the "patch" or "diff" files are also sent to Spark
 Software for inclusion in future releases of the entire package.   A "diff"
 file for the source archives may also contain a compiled version,  provided
 it is  clearly marked as not  being created  from the original source code.
 No other  executable  versions may be  distributed without  the  consent of
 Spark Software.

 3.  You are free to include portions of this source code in any program you
 develop, providing:  a) Credit is given to Spark Software for any code that
 may is used, and  b) The resulting program is free to anyone wanting to use
 it, including commercial and government users.

 4.  There is  NO  technical support  available for dealing with this source
 code, or the accompanying executable files.  This source  code  is provided
 as is, with no warranty expressed or implied (I hate legalease).   In other
 words, if you don't know what to do with it,  don't use it,  and if you are
 brave enough to use it, you're on your own.

 Spark Software may be contacted by modem at (603) 888-8179 (node 1:132/101)
 on the public FidoNet network, or at the address given above.

 To use this code you will need Microsoft C version 4.0, and also Microsoft
 Macro Assembler version 4.0.

*/

/*
   $Log:	TYPES.H $
 * Revision 3.3  87/12/12  00:46:54  Bob
 * Source code release
 * 
*/

/*lint -e29 */

/*
   Message header structure.  The message text is
   just a long string after the header.
*/

struct   _stamp {
      unsigned int date;
      unsigned int time;
	};

typedef struct {
    char from[36];	/* who from */
    char to[36];		/* who to */
    char subj[72];	/* message subject */
    char date[20];	/* creation date */
    int times;			/* number of times read */
    int dest;			/* destination node */
    int orig;			/* originating node */
    int cost;			/* actual cost of msg */
    int orig_net;		/* originating net */
    int dest_net;		/* destination net */
	 struct _stamp _date_written;  /* When user wrote the msg (GMT)        */
    struct _stamp _date_arrived;  /* When msg arrived on-line (GMT)       */
/*    int caca[4]; obsolete *//* extra space */
    int reply;			/* thread to previous message */
    int attr;			/* message type, below */
    int up;				/* thread to next message */
} 
MSG, *MSG_PTR;

/*
	CONFIG.DOG structure used by get_sea_config()
*/

typedef struct {
	int num_addrs;			/* Number of addresses that follow */
	int zone[20];			/* Zone numbers for addresses */
	int net[20];			/* Net numbers */
	int node[20];			/* Node numbers */
	int point[20];			/* Point numbers */
	char mailpath[80];	/* Path to mail directory */
	char filepath[80];	/* Path to attached file directory */
	int baud;				/* Maximum baud rate */
	int comport;			/* Communications port used */
}
SEACONFIG, *SEACONFIG_PTR;

/*
	AREAS.BBS in FastEcho format
*/
typedef struct {
	char *msg_path;
	char *area_name;
	int num_nodes;
	int *msgs_in_area;
	int *zone;
	int *net;
	int *node;
   int *handle;
   char **aname;
   unsigned int flags;
}
AREAS, *AREAS_PTR;

/*
   Passworded structure format
*/
typedef struct {
   int net;
   int node;
   char *password;
}
PW, *PW_PTR;


/*
    MAIL.SYS file structure
*/

typedef struct {
    int node;			/* local node number */
    float fudge;			/* cost fudge factor */
    int rate;			/* baud rate */
    char mailpath[80];		/* path to find mail in */
    char filepath[80];		/* mail file path */
    int net;			/* net number */
    int alt_node;			/* alternate node number */
    int alt_net;			/* alternate net number */
} 
MAIL, *MAIL_PTR;

/*
    Node descriptor (NODELIST.SYS)
*/

typedef struct {
    int number;			/* node number */
    int net;			/* net number */
    int cost;			/* cost per minute to call */
    int rate;			/* baud rate */
    char name[20];			/* node name */
    char phone[40];			/* phone number */
    char city[40];			/* city and state */
} 
NODE, *NODE_PTR;

typedef struct {
    int orig_node;			/* originating node */
    int dest_node;			/* destination node */
    int year,
    month,
    day,
    hour,
    minute,
    second;
    int rate;			/* baud rate */
    int ver;			/* packet version */
    int orig_net;			/* originating net */
    int dest_net;			/* destination net */
	 char product;       /* Product code */
    char rev_lev;       /* revision level */ 
    char password[8];   /* pickup password */ 
    char extra[20];     /* extra space */ 
    long pr_data;       /* product dependent data */ 
} 
PKTHDR, *PKTHDR_PTR;

typedef struct {
	int ver;
	int orig_node;
	int dest_node;
	int orig_net;
	int dest_net;
	int attr;
	int cost;
}
PACKED, *PACKED_PTR;

/*
    User records
*/

typedef struct {
    char name[36];			/* user name */
    char city[36];			/* city and state */
    struct {			/* This structure holds the last */
	int area;			/* message read counters.  It is */
	int last_read;			/* used in place of the commented */
    } 
    msgs_read[10];		/* out 'int date[20];' */
    /*	int date[20];*/			/* initial date */
    char pwd[16];			/* password */
    int times;			/* # times called */
    int help;			/* last help setting */
    int tabs;			/* 1 == expand tabs */
    int nulls;			/* number of nulls */
    int msg;			/* last message area */
    int more;			/* last MORE setting */
    int priv;			/* privilege setting */
    char ldate[20];			/* last time called */
    int time;			/* time on system in 1 day */
    unsigned flag;			/* various bit flags */
    unsigned upld;			/* total K bytes uploaded */
    unsigned dnld;			/* total K bytes downloaded */
    unsigned dnldl;			/* download limiting */
    int files;			/* last file area */
    char width;			/* screen width */
    char len;			/* screen length */
    int credit;			/* credit, in cents */
    int debit;			/* debit, in cents */
} 
USR, *USR_PTR;

typedef struct {
    int calls;			/* # calls in log */
    char fdate[20];			/* logging started */
    char ldate[20];			/* logging ended */
    int log[7][24];			/* the counters */
} 
TLOG, *TLOG_PTR;

/*
    Structure for each virtual bulletin board.
    SYSTEM<n>.BBS files
*/

typedef struct {
    int caller;			/* caller number */
    int priv;			/* min privilege */
    char msgpath[40];		/* path for message base */
    char bbspath[40];		/* path for .BBS files */
    char hlppath[40];		/* path for .HLP files */
    char uppath[40];		/* path for uploads */
    char filepath[40];		/* path for file area */
    int attrib;			/* attributes */
} 
SYS, *SYS_PTR;

typedef struct {
    char name[20];			/* Command name */
    int priv;			/* Command privilege level */
} 
CMD, *CMD_PTR;

typedef struct {
    CMD_PTR menu;			/* Current menu */
    char *bottom_line;			/* Current bottom line */
} 
MENU, *MENU_PTR;

/* Standard time of day structure. */

typedef struct {
     int year;
	  int month;
	  int day;
	  int daywk;
     int hour;
	  int mins;
	  int sec;
/* (daywk == 7 == every day. Month, day, year,
sec not used by sched) */
} TIMESTRCT, *TIMEPTR;

/* Scheduler time structure. */

typedef struct {
     TIMESTRCT time;
     int len;
     int enable;         /* 1 == enabled -1 == 
                            disabled 0 == deleted */
     int trigger;        /* not used (yet) */
     int result;         /* returned value */
     char tag;           /* schedule tag */
	  char extra;			 /* spacer */
     int a,b,c,d,e;      /* extra garbage */
} SCHED, *SCHEDPTR;

/*
    Command structure for the parser.  It is very simple.
    The parser takes the line and breaks it into the first
    four commands that it recognizes.  If the command is a 
    number, then the 'type' field will be that number (NOTE
    that negative numbers are illegal in Fido commands), and
    if the command is a char, then the type will be negative,
    and the command char will be in the 'cmnd' field.
*/

typedef struct {
    int type1;				/* type of command 1 */
    char cmnd1;				/* command 1 if it is a char */
    int type2;				/* type of command 2 */
    char cmnd2;				/* command 2 if it is a char */
    int type3;				/* type of command 3 */
    char cmnd3;				/* command 3 if it is a char */
    int type4;				/* type of command 4 */
    char cmnd4;				/* command 4 if it is a char */
} 
CMND, *CMND_PTR;

typedef struct {
   char *wbuff;
   char *wptr;
   int wsize;
} WBUFFER, *WBUFFPTR;

typedef struct ktype {
	long seconds;
	unsigned int from;
	unsigned int to;
	unsigned int subject;
} KILL, *KILLPTR;

typedef struct {
   KILLPTR klink;
	int msg_num;
   char deleted;
   char replied;
} KILL2, *KILL2PTR;

